@@ -165,8 +165,12 @@ Optimizer = R6Class("Optimizer",
 #' @export
 assign_result_default = function(inst) {
   assert_r6(inst, "OptimInstance")
+
   res = inst$archive$best()
-  xdt = res[, inst$search_space$ids(), with = FALSE]
+  ids = inst$search_space$ids()
+  # workaround until ... works
+  if ("internal_tuned_values" %in% names(res)) ids = c(ids, "internal_tuned_values")
+  xdt = res[, ids, with = FALSE]
 
   if (inherits(inst, "OptimInstanceBatchMultiCrit") || inherits(inst, "OptimInstanceAsyncMultiCrit")) {
     ydt = res[, inst$archive$cols_y, with = FALSE]
