@@ -4,7 +4,7 @@ test_that("mlr_optimizers", {
 
   for (key in keys) {
     optimizer = opt(key)
-    expect_r6(optimizer, "Optimizer")
+    expect_multi_class(optimizer, c("Optimizer", "OptimizerAsync"))
   }
 })
 
@@ -16,5 +16,5 @@ test_that("mlr_optimizers sugar", {
 test_that("as.data.table objects parameter", {
   tab = as.data.table(mlr_optimizers, objects = TRUE)
   expect_data_table(tab)
-  expect_list(tab$object, "Optimizer", any.missing = FALSE)
+  expect_list(tab$object, any.missing = FALSE)
 })
